rename bypass to bypassed
--- diff/drivers/md/dm-mpath.c	2004-10-29 15:39:50.000000000 +0100
+++ source/drivers/md/dm-mpath.c	2004-10-29 15:39:56.000000000 +0100
@@ -40,7 +40,7 @@
 	struct path_selector ps;
 
 	unsigned nr_paths;
-	unsigned bypass;		/* Temporarily bypass this PG */
+	unsigned bypassed;		/* Temporarily bypass this PG */
 	struct list_head paths;
 };
 
@@ -208,19 +208,19 @@
 {
 	struct priority_group *pg;
 	struct path *path = NULL;
-	unsigned bypass = 1;
+	unsigned bypassed = 1;
 
 	if (!m->nr_valid_paths)
 		goto out;
 
 	/*
 	 * Loop through priority groups until we find a valid path.
-	 * First time we skip PGs marked 'bypass'.
+	 * First time we skip PGs marked 'bypassed'.
 	 * Second time we only try the ones we skipped.
 	 */
 	do {
 		list_for_each_entry (pg, &m->priority_groups, list) {
-			if (pg->bypass == bypass)
+			if (pg->bypassed == bypassed)
 				continue;
 			path = pg->ps.type->select_path(&pg->ps,
 							&m->current_count);
@@ -232,7 +232,7 @@
 
 			goto out;
 		}
-	} while (bypass--);
+	} while (bypassed--);
 
 out:
 	m->current_path = path;
@@ -322,7 +322,7 @@
 		__choose_path(m);
 
 	path = m->current_path;
-	bypassed = path->pg->bypass;
+	bypassed = path->pg->bypassed;
 	must_queue = m->queue_io;
 
 	init_required = m->pg_init_required;
@@ -725,12 +725,12 @@
 }
 
 static void bypass_pg(struct multipath *m, struct priority_group *pg,
-		      int bypass)
+		      int bypassed)
 {
 	unsigned long flags;
 
 	spin_lock_irqsave(&m->lock, flags);
-	pg->bypass = bypass;
+	pg->bypassed = bypassed;
 	m->current_path = NULL;
 	m->current_pg = NULL;
 	spin_unlock_irqrestore(&m->lock, flags);
@@ -739,10 +739,10 @@
 }
 
 /*
- * Set/clear bypass status of a PG.
+ * Set/clear bypassed status of a PG.
  * PG numbering goes 1, 2, 3...
  */
-static int bypass_pg_num(struct multipath *m, const char *pgstr, int bypass)
+static int bypass_pg_num(struct multipath *m, const char *pgstr, int bypassed)
 {
 	struct priority_group *pg;
 	unsigned pgnum;
@@ -754,7 +754,7 @@
 		if (--pgnum)
 			continue;
 
-		bypass_pg(m, pg, bypass);
+		bypass_pg(m, pg, bypassed);
 
 		return 0;
 	}
@@ -774,7 +774,7 @@
 	unsigned long flags;
 
 	/* We insist on failing the path if the PG is already bypassed. */
-	if (err_flags && pg->bypass)
+	if (err_flags && pg->bypassed)
 		err_flags |= MP_FAIL_PATH;
 
 	if (err_flags & MP_FAIL_PATH)
@@ -883,7 +883,7 @@
 	case STATUSTYPE_INFO:
 
 		list_for_each_entry(pg, &m->priority_groups, list) {
-			if (pg->bypass)
+			if (pg->bypassed)
 				state = 'D';	/* Disabled */
 			else if (pg == m->current_pg)
 				state = 'A';	/* Currently Active */
